@@ -25,14 +25,14 @@ let lablgtk_mls = split "gaux gpointer gutf8 glib gobject gdkEnums pangoEnums gt
 let extra_mls = split "gtkInit gtkThread gtkThInit"
 let prop_mls = split "gtkBaseProps gtkBinProps gtkButtonProps gtkEditProps gtkListProps gtkMenuProps gtkMiscProps gtkPackProps gtkRangeProps gtkTextProps gtkTreeProps gtkFileProps gtkActionProps gtkBrokenProps gtkAssistantProps ogtkBaseProps ogtkBinProps ogtkButtonProps ogtkEditProps ogtkListProps ogtkMenuProps ogtkMiscProps ogtkPackProps ogtkRangeProps ogtkTextProps ogtkTreeProps ogtkFileProps ogtkActionProps ogtkBrokenProps ogtkAssistantProps"
 let gtk_libs = "-lgtk-x11-2.0 -lgdk-x11-2.0 -lpangocairo-1.0 -latk-1.0 -lcairo -lgdk_pixbuf-2.0 -lgio-2.0 -lpangoft2-1.0 -lpango-1.0 -lgobject-2.0 -lglib-2.0 -lintl -lfontconfig -lfreetype"
-let glade_mls = split "glade"
-let glade_libs = "-lglade-2.0 -lgtk-x11-2.0 -lgdk-x11-2.0 -lpangocairo-1.0 -latk-1.0 -lcairo -lgdk_pixbuf-2.0 -lgio-2.0 -lpangoft2-1.0 -lpango-1.0 -lgobject-2.0 -lglib-2.0 -lintl -lfontconfig -lfreetype -lxml2"
+let glade_mls = split ""
+let glade_libs = ""
 let rsvg_mls = split "rsvg"
 let rsvg_libs = "-lrsvg-2 -lm -lgio-2.0 -lgdk_pixbuf-2.0 -lgobject-2.0 -lglib-2.0 -lintl -lcairo"
-let canvas_mls = split "gnomeCanvas gnoCanvas"
-let canvas_libs = "-lgnomecanvas-2 -lart_lgpl_2 -lgtk-x11-2.0 -lgdk-x11-2.0 -lpangocairo-1.0 -latk-1.0 -lcairo -lgdk_pixbuf-2.0 -lgio-2.0 -lpangoft2-1.0 -lpango-1.0 -lgobject-2.0 -lglib-2.0 -lintl -lfontconfig -lfreetype"
-let sourceview2_mls = split "sourceView2Enums gtkSourceView2Props ogtkSourceView2Props gtkSourceView2 gSourceView2"
-let sourceview2_libs = "-lgtksourceview-2.0 -lgtk-x11-2.0 -lgdk-x11-2.0 -lpangocairo-1.0 -latk-1.0 -lcairo -lgdk_pixbuf-2.0 -lgio-2.0 -lpangoft2-1.0 -lpango-1.0 -lgobject-2.0 -lglib-2.0 -lintl -lfontconfig -lfreetype"
+let canvas_mls = split ""
+let canvas_libs = ""
+let sourceview2_mls = split ""
+let sourceview2_libs = ""
 
 (* Hack to check for mingw *)
 let () =
